@@ -532,7 +532,7 @@ exaPolylines(DrawablePtr pDrawable, GCPtr pGC, int mode, int npt,
     x1 = ppt[0].x;
     y1 = ppt[0].y;
     /* If we have any non-horizontal/vertical, fall back. */
-    for (i = 0; i < npt; i++) {
+    for (i = 0; i < npt - 1; i++) {
 	if (mode == CoordModePrevious) {
 	    x2 = x1 + ppt[i + 1].x;
 	    y2 = y1 + ppt[i + 1].y;
@@ -613,6 +613,14 @@ exaPolySegment (DrawablePtr pDrawable, GCPtr pGC, int nseg,
 	    prect[i].y = pSeg[i].y2;
 	    prect[i].height = pSeg[i].y1 - pSeg[i].y2 + 1;
 	}
+
+	/* don't paint last pixel */
+	if (pGC->capStyle == CapNotLast) {
+		if (prect[i].width == 1) 
+			prect[i].height--;
+		else
+			prect[i].width--;
+	}
     }
     pGC->ops->PolyFillRect(pDrawable, pGC, nseg, prect);
     DEALLOCATE_LOCAL(prect);
