@@ -12,7 +12,7 @@
 #define I830_I2C_BUS_DVO 1
 #define I830_I2C_BUS_SDVO 2
 
-/* these are outputs from the chip - integrated only 
+/* these are outputs from the chip - integrated only
    external chips are via DVO or SDVO output */
 #define I830_OUTPUT_UNUSED 0
 #define I830_OUTPUT_ANALOG 1
@@ -45,7 +45,10 @@
 
 extern DisplayModePtr i830_ddc_get_modes(xf86OutputPtr output);
 extern void i830_lvds_init(ScrnInfoPtr pScrn);
-extern Bool
-I830I2CInit(ScrnInfoPtr pScrn, I2CBusPtr * bus_ptr, int i2c_reg, char *name);
+extern void i830_set_lvds_blc_data(ScrnInfoPtr pScrn, CARD8 blctype,
+				   CARD8 pol, CARD16 freq, CARD8 minlevel,
+				   CARD8 address, CARD8 level);
+extern Bool I830I2CInit(ScrnInfoPtr pScrn, I2CBusPtr * bus_ptr, int i2c_reg,
+			char *name);
 
 #endif
