@@ -1,5 +1,5 @@
 /**************************************************************************
- * 
+ *
  * Copyright (c) Intel Corp. 2007.
  * All Rights Reserved.
  *
@@ -17,19 +17,18 @@
  * The above copyright notice and this permission notice (including the
  * next paragraph) shall be included in all copies or substantial portions
  * of the Software.
- * 
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL
  * THE COPYRIGHT HOLDERS, AUTHORS AND/OR ITS SUPPLIERS BE LIABLE FOR ANY CLAIM,
- * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
- * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE 
+ * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
+ * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
  * USE OR OTHER DEALINGS IN THE SOFTWARE.
  *
  **************************************************************************/
 /*
  */
-
 #include <stdio.h>
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -37,14 +36,16 @@
 #include <psb_reg.h>
 #include "psb_driver.h"
 #include "psb_dri.h"
-
 #define _XF86DRI_SERVER_
 #include "GL/glxtokens.h"
 #include "GL/glxint.h"
 #include "sarea.h"
-
 #define PSB_DRI_LOCK_SAREA_SIZE SAREA_MAX
 
+#define PSB_NUM_ACCUM 2
+#define PSB_NUM_STENCIL 2
+#define PSB_NUM_DB 2
+
 typedef struct
 {
     int major;
@@ -56,10 +57,13 @@ static char *psbKernelDriverName = "psb";
 static char *psbClientDriverName = "psb";
 
 /* The earliest version this code works with */
-static const PsbDRMVersion drmExpected = { 0, 1, 0 };
+static const PsbDRMVersion drmExpected = { 3, 0, 0 };
 
 /* But also compatible with the major version of : */
-static const PsbDRMVersion drmCompat = { 0, 0, 0 };
+static const PsbDRMVersion drmCompat = { 4, 0, 0 };
+
+static const PsbDRMVersion boExpected = { 1, 0, 0 };
+static const PsbDRMVersion boCompat = { 1, 0, 0 };
 
 static const char *driReqSymbols[] = {
     "GlxSetVisualConfigs",
@@ -69,26 +73,27 @@ static const char *driReqSymbols[] = {
 };
 
 extern void GlxSetVisualConfigs(int nconfigs,
-    __GLXvisualConfig * configs, void **configprivs);
+				__GLXvisualConfig * configs,
+				void **configprivs);
 
 static Bool
 psbDRICreateContext(ScreenPtr pScreen, VisualPtr visual,
-    drm_context_t hwContext, void *pVisualConfigPriv,
-    DRIContextType contextStore)
+		    drm_context_t hwContext, void *pVisualConfigPriv,
+		    DRIContextType contextStore)
 {
     return TRUE;
 }
 
 static void
 psbDRIDestroyContext(ScreenPtr pScreen, drm_context_t hwContext,
-    DRIContextType contextStore)
+		     DRIContextType contextStore)
 {
 }
 
 static void
 psbDRISwapContext(ScreenPtr pScreen, DRISyncType syncType,
-    DRIContextType oldContextType, void *oldContext,
-    DRIContextType newContextType, void *newContext)
+		  DRIContextType oldContextType, void *oldContext,
+		  DRIContextType newContextType, void *newContext)
 {
 }
 
@@ -99,10 +104,33 @@ psbDRIInitBuffers(WindowPtr pWin, RegionPtr prgn, CARD32 index)
 
 static void
 psbDRIMoveBuffers(WindowPtr pParent, DDXPointRec ptOldOrg,
-    RegionPtr prgnSrc, CARD32 index)
+		  RegionPtr prgnSrc, CARD32 index)
 {
 }
 
+static Bool
+psbDRICheckVersion(ScrnInfoPtr pScrn,
+		   const char *component, int major, int minor,
+		   int patchlevel, const PsbDRMVersion * expected,
+		   const PsbDRMVersion * compat)
+{
+    if ((major < expected->major) ||
+	(major > compat->major) ||
+	((major == expected->major) && (minor < expected->minor))) {
+	xf86DrvMsg(pScrn->scrnIndex, X_WARNING,
+		   "[drm] %s is not compatible with this driver.\n"
+		   "\tKernel %s version: %d.%d.%d\n"
+		   "\tand I can work with versions %d.%d.x - %d.x.x\n"
+		   "\tPlease update either this 2D driver or your kernel DRM.\n"
+		   "\tDisabling DRI.\n",
+		   component, component,
+		   major, minor, patchlevel,
+		   expected->major, expected->minor, compat->major);
+	return FALSE;
+    }
+    return TRUE;
+}
+
 void
 psbDRMIrqInit(PsbDevicePtr pDevice)
 {
@@ -111,14 +139,15 @@ psbDRMIrqInit(PsbDevicePtr pDevice)
 	return;
 
     pDevice->irq = drmGetInterruptFromBusID(pDevice->drmFD,
-	pDevice->pciInfo->bus,
-	pDevice->pciInfo->device, pDevice->pciInfo->func);
+					    pDevice->pciInfo->bus,
+					    pDevice->pciInfo->device,
+					    pDevice->pciInfo->func);
     if ((drmCtlInstHandler(pDevice->drmFD, pDevice->irq))) {
 	xf86DrvMsg(-1, X_WARNING, "[drm] Failed to install IRQ handler.\n");
 	pDevice->irq = -1;
     } else {
 	xf86DrvMsg(-1, X_INFO, "[drm] Irq handler installed for IRQ %d.\n",
-	    pDevice->irq);
+		   pDevice->irq);
     }
 }
 
@@ -162,17 +191,21 @@ psbDeviceLegacyDRIInit(ScreenPtr pScreen)
     PsbDevicePtr pDevice = psbDevicePTR(pPsb);
     DRIInfoPtr pDRIInfo = pDRIInfo = pPsb->pDRIInfo;
     drmVersionPtr drmVer;
+    unsigned int boMajor;
+    unsigned int boMinor;
+    unsigned int boPatchLevel;
 
     pDevice->drmFD = pPsb->drmFD;
     pDevice->busIdString = pDRIInfo->busIdString;
     pDevice->lockRefCount = 0;
     pDevice->pLSAREA = (void *)
-	((unsigned long)DRIGetSAREAPrivate(pScreen) - sizeof(XF86DRISAREARec));
+	((unsigned long)DRIGetSAREAPrivate(pScreen) -
+	 sizeof(XF86DRISAREARec));
 
     drmVer = drmGetVersion(pDevice->drmFD);
     if (!drmVer) {
 	xf86DrvMsg(pScrn->scrnIndex,
-	    X_ERROR, "[drm] Could not get the DRM version.\n");
+		   X_ERROR, "[drm] Could not get the DRM version.\n");
 	goto out_err;
     }
 
@@ -181,29 +214,31 @@ psbDeviceLegacyDRIInit(ScreenPtr pScreen)
     pDevice->drmVerPL = drmVer->version_patchlevel;
     drmFreeVersion(drmVer);
 
-    if ((pDevice->drmVerMajor < drmExpected.major) ||
-	(pDevice->drmVerMajor > drmCompat.major) ||
-	((pDevice->drmVerMajor == drmExpected.major) &&
-	    (pDevice->drmVerMinor < drmExpected.minor))) {
-	xf86DrvMsg(pScrn->scrnIndex, X_WARNING,
-	    "[drm] DRM is not compatible with this driver.\n"
-	    "\tKernel DRM version: %d.%d.%d\n"
-	    "\tand I can work with versions %d.%d.x - %d.x.x\n"
-	    "\tPlease update either this 2D driver or your kernel DRM.\n"
-	    "\tDisabling DRI.\n",
-	    pDevice->drmVerMajor, pDevice->drmVerMinor,
-	    pDevice->drmVerPL, drmExpected.major,
-	    drmExpected.minor, drmCompat.major);
+    if (!psbDRICheckVersion(pScrn, "DRM", pDevice->drmVerMajor,
+			    pDevice->drmVerMinor,
+			    pDevice->drmVerPL, &drmExpected, &drmCompat))
+	goto out_err;
+
+    if (drmBOVersion(pDevice->drmFD, &boMajor, &boMinor, &boPatchLevel)
+	!= 0) {
+	xf86DrvMsg(pScrn->scrnIndex,
+		   X_ERROR, "[drm] Could not get the DRM "
+		   "Buffer manager version: %s\n", strerror(errno));
 	goto out_err;
     }
+
+    if (!psbDRICheckVersion(pScrn, "Buffer Manager", boMajor,
+			    boMinor, boPatchLevel, &boExpected, &boCompat))
+	goto out_err;
+
     if (drmCreateContext(pDevice->drmFD, &pDevice->drmContext) < 0) {
 	xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
-	    "[drm] Could not create a drm device context.\n");
+		   "[drm] Could not create a drm device context.\n");
 	goto out_err;
     } else {
 	xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-	    "[drm] Allocated device DRM context %d.\n",
-	    (int)pDevice->drmContext);
+		   "[drm] Allocated device DRM context %d.\n",
+		   (int)pDevice->drmContext);
     }
 
     pDevice->hasDRM = TRUE;
@@ -237,6 +272,9 @@ Bool
 psbDRMDeviceInit(PsbDevicePtr pDevice)
 {
     drmVersionPtr drmVer;
+    unsigned int boMajor;
+    unsigned int boMinor;
+    unsigned int boPatchLevel;
 
     pDevice->drmFD = -1;
     pDevice->busIdString = NULL;
@@ -247,12 +285,12 @@ psbDRMDeviceInit(PsbDevicePtr pDevice)
 	goto out_err;
 
     sprintf(pDevice->busIdString, "PCI:%d:%d:%d",
-	pDevice->pciInfo->bus,
-	pDevice->pciInfo->device, pDevice->pciInfo->func);
+	    pDevice->pciInfo->bus,
+	    pDevice->pciInfo->device, pDevice->pciInfo->func);
 
     if (!DRIOpenDRMMaster(pDevice->pScrns[0],
-	    PSB_DRI_LOCK_SAREA_SIZE, pDevice->busIdString,
-	    psbKernelDriverName))
+			  PSB_DRI_LOCK_SAREA_SIZE, pDevice->busIdString,
+			  psbKernelDriverName))
 	goto out_err;
 
     pDevice->drmFD = DRIMasterFD(pDevice->pScrns[0]);
@@ -270,34 +308,35 @@ psbDRMDeviceInit(PsbDevicePtr pDevice)
     pDevice->drmVerPL = drmVer->version_patchlevel;
     drmFreeVersion(drmVer);
 
-    if ((pDevice->drmVerMajor < drmExpected.major) ||
-	(pDevice->drmVerMajor > drmCompat.major) ||
-	((pDevice->drmVerMajor == drmExpected.major) &&
-	    (pDevice->drmVerMinor < drmExpected.minor))) {
-	xf86DrvMsg(-1, X_WARNING,
-	    "[drm] DRM is not compatible with this driver.\n"
-	    "\tKernel DRM version: %d.%d.%d\n"
-	    "\tand I can work with versions %d.%d.x - %d.x.x\n"
-	    "\tPlease update either this 2D driver or your kernel DRM.\n"
-	    "\tDisabling DRI.\n",
-	    pDevice->drmVerMajor, pDevice->drmVerMinor,
-	    pDevice->drmVerPL, drmExpected.major,
-	    drmExpected.minor, drmCompat.major);
+    if (!psbDRICheckVersion(pScrn, "DRM", pDevice->drmVerMajor,
+			    pDevice->drmVerMinor,
+			    pDevice->drmVerPL, &drmExpected, &drmCompat))
+	goto out_err;
+
+    if (drmBOVersion(pDevice->drmFD, &boMajor, &boMinor, &boPatchLevel)
+	!= 0) {
+	xf86DrvMsg(pScrn->scrnIndex,
+		   X_ERROR, "[drm] Could not get the DRM "
+		   "Buffer manager version.\n");
 	goto out_err;
     }
 
+    if (!psbDRICheckVersion(pScrn, "Buffer Manager", boMajor,
+			    boMinor, boPatchLevel, &boExpected, &boCompat))
+	goto out_err;
+
     /*
      * Create a device context.
      */
 
     if (drmCreateContext(pDevice->drmFD, &pDevice->drmContext) < 0) {
 	xf86DrvMsg(-1, X_ERROR,
-	    "[drm] Could not create a drm device context.\n");
+		   "[drm] Could not create a drm device context.\n");
 	goto out_err;
     } else {
 	xf86DrvMsg(-1, X_INFO,
-	    "[drm] Allocated device DRM context %d.\n",
-	    (int)pDevice->drmContext);
+		   "[drm] Allocated device DRM context %d.\n",
+		   (int)pDevice->drmContext);
     }
 
     pDevice->hasDRM = TRUE;
@@ -330,13 +369,13 @@ static Bool
 psbAllocConfigRec(int numConfigs, PsbGLXConfigPtr pGLX)
 {
     if (!(pGLX->pConfigs = (__GLXvisualConfig *)
-	    xcalloc(sizeof(__GLXvisualConfig), numConfigs)))
+	  xcalloc(sizeof(__GLXvisualConfig), numConfigs)))
 	goto out_err;
     if (!(pGLX->pPsbConfigs = (PsbConfigPrivPtr)
-	    xcalloc(sizeof(PsbConfigPrivRec), numConfigs)))
+	  xcalloc(sizeof(PsbConfigPrivRec), numConfigs)))
 	goto out_err;
     if (!(pGLX->pPsbConfigPtrs = (PsbConfigPrivPtr *)
-	    xcalloc(sizeof(PsbConfigPrivPtr), numConfigs)))
+	  xcalloc(sizeof(PsbConfigPrivPtr), numConfigs)))
 	goto out_err;
     pGLX->numConfigs = numConfigs;
 
@@ -354,22 +393,16 @@ psbSetupStencil(int stencil, __GLXvisualConfig * pConfigs)
 	pConfigs->depthSize = 24;
 	pConfigs->stencilSize = 8;
 	break;
+#if 0
     case 1:
 	pConfigs->depthSize = 16;
 	pConfigs->stencilSize = 0;
 	break;
-    case 2:
+#endif
+    case 1:
 	pConfigs->depthSize = 0;
 	pConfigs->stencilSize = 0;
 	break;
-    case 3:
-	pConfigs->depthSize = 32;
-	pConfigs->stencilSize = 0;
-	break;
-    case 4:
-	pConfigs->depthSize = 32;
-	pConfigs->stencilSize = 8;
-	break;
     }
 }
 
@@ -440,14 +473,14 @@ psbInitVisualConfigs(ScreenPtr pScreen)
 	break;
     case 15:
     case 16:
-	numConfigs = 20;
+	numConfigs = PSB_NUM_ACCUM * PSB_NUM_STENCIL * PSB_NUM_DB;
 	if (!psbAllocConfigRec(numConfigs, &psbGLX))
 	    return FALSE;
 
 	i = 0;
-	for (accum = 0; accum < 2; accum++) {
-	    for (stencil = 0; stencil < 5; stencil++) {
-		for (db = 0; db < 2; db++) {
+	for (accum = 0; accum < PSB_NUM_ACCUM; accum++) {
+	    for (stencil = 0; stencil < PSB_NUM_STENCIL; stencil++) {
+		for (db = 0; db < PSB_NUM_DB; db++) {
 		    pConfigs = &psbGLX.pConfigs[i];
 		    psbSetupInitial(pConfigs);
 		    psbSetupDB(db, pConfigs);
@@ -460,14 +493,14 @@ psbInitVisualConfigs(ScreenPtr pScreen)
 	break;
     case 24:
     case 32:
-	numConfigs = 20;
+	numConfigs = PSB_NUM_ACCUM * PSB_NUM_STENCIL * PSB_NUM_DB;
 	if (!psbAllocConfigRec(numConfigs, &psbGLX))
 	    return FALSE;
 
 	i = 0;
-	for (accum = 0; accum < 2; accum++) {
-	    for (stencil = 0; stencil < 5; stencil++) {
-		for (db = 0; db < 2; db++) {
+	for (accum = 0; accum < PSB_NUM_ACCUM; accum++) {
+	    for (stencil = 0; stencil < PSB_NUM_STENCIL; stencil++) {
+		for (db = 0; db < PSB_NUM_DB; db++) {
 		    pConfigs = &psbGLX.pConfigs[i];
 		    psbSetupInitial(pConfigs);
 		    pConfigs->alphaSize = 8;
@@ -484,7 +517,7 @@ psbInitVisualConfigs(ScreenPtr pScreen)
 
     pPsb->glx = psbGLX;
     GlxSetVisualConfigs(numConfigs, psbGLX.pConfigs,
-	(void **)psbGLX.pPsbConfigPtrs);
+			(void **)psbGLX.pPsbConfigPtrs);
     return TRUE;
 }
 
@@ -497,8 +530,9 @@ psbDRIScreenInit(ScreenPtr pScreen)
     DRIInfoPtr pDRIInfo;
     PsbDRIPtr pPsbDRI;
     int major, minor, patch;
+    pciVideoPtr pciInfo;
 
-    PSB_DEBUG(pScrn->scrnIndex, 2, "psbDRIScreenInit\n");
+    PSB_DEBUG(pScrn->scrnIndex, 3, "psbDRIScreenInit\n");
 
     xf86LoaderReqSymLists(driReqSymbols, NULL);
 
@@ -511,27 +545,31 @@ psbDRIScreenInit(ScreenPtr pScreen)
     DRIQueryVersion(&major, &minor, &patch);
     if (major != DRIINFO_MAJOR_VERSION || minor < DRIINFO_MINOR_VERSION) {
 	xf86DrvMsg(pScreen->myNum, X_ERROR,
-	    "[dri] Incorrect Xserver libdri version %d.%d.%d.\n"
-	    "\tVersion %d.%d.x needed. Disabling dri.\n",
-	    major, minor, patch,
-	    DRIINFO_MAJOR_VERSION, DRIINFO_MINOR_VERSION);
+		   "[dri] Incorrect Xserver libdri version %d.%d.%d.\n"
+		   "\tVersion %d.%d.x needed. Disabling dri.\n",
+		   major, minor, patch,
+		   DRIINFO_MAJOR_VERSION, DRIINFO_MINOR_VERSION);
 	goto out_err;
     }
 
     pPsb->pDRIInfo = DRICreateInfoRec();
     if (!pPsb->pDRIInfo) {
 	xf86DrvMsg(pScreen->myNum, X_ERROR,
-	    "[dri] Failed allocating DRIInfo structure. Disabling DRI.\n");
+		   "[dri] Failed allocating DRIInfo structure. Disabling DRI.\n");
 	goto out_err;
     }
 
     pDRIInfo = pPsb->pDRIInfo;
     pDRIInfo->drmDriverName = psbKernelDriverName;
-    pDRIInfo->clientDriverName = psbClientDriverName;
+    /* if Xpsb not available hack it that there's no driver available */
+    if (!pPsb->noAccel && pPsb->xpsb)
+	pDRIInfo->clientDriverName = psbClientDriverName;
+    else
+	pDRIInfo->clientDriverName = NULL;
     pDRIInfo->busIdString = xalloc(64);
     sprintf(pDRIInfo->busIdString, "PCI:%d:%d:%d",
-	pDevice->pciInfo->bus,
-	pDevice->pciInfo->device, pDevice->pciInfo->func);
+	    pDevice->pciInfo->bus,
+	    pDevice->pciInfo->device, pDevice->pciInfo->func);
     pDRIInfo->ddxDriverMajorVersion = PSB_DRIDDX_VERSION_MAJOR;
     pDRIInfo->ddxDriverMinorVersion = PSB_DRIDDX_VERSION_MINOR;
     pDRIInfo->ddxDriverPatchVersion = PSB_DRIDDX_VERSION_PATCH;
@@ -547,7 +585,8 @@ psbDRIScreenInit(ScreenPtr pScreen)
 
     pDRIInfo->ddxDrawableTableEntry = SAREA_MAX_DRAWABLES;
     pDRIInfo->maxDrawableTableEntry = SAREA_MAX_DRAWABLES;
-    pDRIInfo->SAREASize = (sizeof(XF86DRISAREARec) + sizeof(drm_psb_sarea_t));
+    pDRIInfo->SAREASize =
+	(sizeof(XF86DRISAREARec) + sizeof(struct drm_psb_sarea));
     pDRIInfo->SAREASize = ALIGN_TO(pDRIInfo->SAREASize, PSB_PAGE_SIZE);
 
     /*
@@ -559,17 +598,18 @@ psbDRIScreenInit(ScreenPtr pScreen)
 	pDRIInfo->SAREASize : SAREA_MAX;
 
     PSB_DEBUG(pScrn->scrnIndex, 3, "SAREA size is %ld\n",
-	pDRIInfo->SAREASize);
+	      pDRIInfo->SAREASize);
 
     pDRIInfo->devPrivate = NULL;
     if (!(pPsbDRI = (PsbDRIPtr) xcalloc(sizeof(*pPsbDRI), 1))) {
 	xf86DrvMsg(pScreen->myNum, X_ERROR,
-	    "[dri] Failed allocating DRI driver structure. Disabling DRI.\n");
+		   "[dri] Failed allocating DRI driver structure. Disabling DRI.\n");
 	goto out_err;
     }
 
     pPsbDRI->pciVendor = PCI_VENDOR_INTEL;
-    pPsbDRI->pciDevice = PCI_CHIP_PSB;
+    pciInfo = xf86GetPciInfoForEntity(pDevice->pEnt->index);
+    pPsbDRI->pciDevice = pciInfo->chipType;
     pPsbDRI->lockSAreaSize = PSB_DRI_LOCK_SAREA_SIZE;
 #if PSB_LEGACY_DRI
     pPsbDRI->lockSAreaHandle = 0;
@@ -594,16 +634,15 @@ psbDRIScreenInit(ScreenPtr pScreen)
 
     if (!DRIScreenInit(pScreen, pDRIInfo, &pPsb->drmFD)) {
 	xf86DrvMsg(pScreen->myNum, X_ERROR,
-	    "[dri] DRIScreenInit failed. Disabling DRI.\n");
+		   "[dri] DRIScreenInit failed. Disabling DRI.\n");
 	goto out_err;
     }
 
     if (!psbInitVisualConfigs(pScreen)) {
 	xf86DrvMsg(pScreen->myNum, X_ERROR,
-	    "[dri] Could not initialize GLX visuals. Disabling DRI.\n");
+		   "[dri] Could not initialize GLX visuals. Disabling DRI.\n");
 	goto out_err;
     }
-
 #if PSB_LEGACY_DRI
     if (!psbDeviceLegacyDRIInit(pScreen))
 	goto out_err;
@@ -616,17 +655,21 @@ psbDRIScreenInit(ScreenPtr pScreen)
     return FALSE;
 }
 
-
-
 Bool
 psbDRIFinishScreenInit(ScreenPtr pScreen)
 {
     ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
     PsbPtr pPsb = psbPTR(pScrn);
 
+    /* avoid install sigio handler here */
+    pPsb->pDRIInfo->driverSwapMethod = DRI_KERNEL_SWAP;
+
     if (!DRIFinishScreenInit(pScreen))
 	goto out_err;
 
+    /* now put it back to X, for the blockhandlers to work */
+    pPsb->pDRIInfo->driverSwapMethod = DRI_HIDE_X_CONTEXT;
+
     pPsb->driEnabled = TRUE;
     psbDRIUpdateScanouts(pScrn);
     return TRUE;
@@ -678,7 +721,7 @@ psbDRILock(ScrnInfoPtr pScrn, int flags)
 	if (pDevice->hasDRM) {
 	    if (!pDevice->lockRefCount)
 		DRM_LOCK(pDevice->drmFD, pDevice->pLSAREA,
-		    pDevice->drmContext, flags);
+			 pDevice->drmContext, flags);
 	    pDevice->lockRefCount++;
 	}
     }
@@ -700,12 +743,12 @@ psbDRIUnlock(ScrnInfoPtr pScrn)
 		--pDevice->lockRefCount;
 	    else {
 		xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
-		    "psbDRIUnlock called when not locked.\n");
+			   "psbDRIUnlock called when not locked.\n");
 		return;
 	    }
 	    if (!pDevice->lockRefCount)
 		DRM_UNLOCK(pDevice->drmFD, pDevice->pLSAREA,
-		    pDevice->drmContext);
+			   pDevice->drmContext);
 	}
     }
 }
@@ -717,16 +760,16 @@ psbDRIUpdateScanouts(ScrnInfoPtr pScrn)
     MMListHead *list;
     PsbScanoutPtr scanOut;
     int index = 0;
-    drm_psb_scanout_t *drmScanOut;
-    drm_psb_sarea_t *pSarea;
+    struct drm_psb_scanout *drmScanOut;
+    struct drm_psb_sarea *pSarea;
     struct _MMBuffer *buf;
 
-    PSB_DEBUG(pScrn->scrnIndex, 2, "PsbDRIUpdateScanouts\n");
+    PSB_DEBUG(pScrn->scrnIndex, 3, "PsbDRIUpdateScanouts\n");
 
     if (!pPsb->driEnabled)
 	return;
 
-    pSarea = (drm_psb_sarea_t *) DRIGetSAREAPrivate(pScrn->pScreen);
+    pSarea = (struct drm_psb_sarea *)DRIGetSAREAPrivate(pScrn->pScreen);
 
     mmListForEach(list, &pPsb->sAreaList) {
 	scanOut = mmListEntry(list, PsbScanoutRec, sAreaList);
@@ -741,8 +784,8 @@ psbDRIUpdateScanouts(ScrnInfoPtr pScrn)
 	drmScanOut->height = psbScanoutHeight(scanOut);
 
 	PSB_DEBUG(pScrn->scrnIndex, 3,
-	    "Buffer %d rotation %d handle 0x%08x\n", index,
-	    drmScanOut->rotation, drmScanOut->buffer_id);
+		  "Buffer %d rotation %d handle 0x%08x\n", index,
+		  drmScanOut->rotation, drmScanOut->buffer_id);
 
 	++index;
     }
